@@ -1,4 +1,4 @@
-version = "0.0.20"
+version = "0.0.25"
 author = "RedHog (Egil Moeller)"
 author_email = "egil.moller@freecode.no"
 license = "GPL"
@@ -7,4 +7,4 @@ name = "appomatic_django_cms"
 description = "Get the pony powered CMS With Frontend-Editing"
 keywords = "appomatic django-cms"
 url = "https://www.django-cms.org"
-install_requires = ['django==1.3.1', 'django-cms']
+install_requires = ['django-cms']
